@@ -3,17 +3,15 @@
 import dbi
 
 for d in dbi.available_drivers():
-	print d;
+	print(d);
 	try:
 		for s in dbi.data_sources(d):
-			print "  ", s
+			print("  ", s)
 	except:
 		pass
-print "----"
+print("----")
 
-#dbh = dbi.connect("dbi:NullP:")
-
-#$dbh = DBI->connect("DBI:mysql:database=fotodb", "gisle", "",
+#$dbh = DBI->connect("DBI:mysql:database=test", "snake", "",
 #                    {
 #                      RaiseError => 1,
 #                      PrintError => 0,
@@ -21,7 +19,7 @@ print "----"
 #                    }) || die;
 
 
-dbh = dbi.connect("DBI:mysql:database=fotodb", "gisle",
+dbh = dbi.connect("DBI:mysql:database=test", "snake",
 		  RaiseError = 1,
 		  PrintError = 0,
 		  AutoCommit = 1,
@@ -30,15 +28,15 @@ dbh = dbi.connect("DBI:mysql:database=fotodb", "gisle",
 try:
     dbh["AutoCommit"] = 0
 except:
-    print "Can't turn off AutoCommit"
+    print("Can't turn off AutoCommit")
 
 sth = dbh.prepare("select * from img limit 5")
 rows = sth.execute()
-print rows
+print(rows)
 
 while 1:
 	row = sth.fetchrow_tuple()
         if not row: break
-	print row
+	print(row)
 
 dbh.disconnect()
